import PropTypes from "prop-types";
import { CSSProperties, SyntheticEvent } from "react";
import { ColumnDescription, TableColumnFilterProps } from "react-bootstrap-table-nextgen";
import DateFilter from "./src/components/date";
import MultiSelectFilter from "./src/components/multiselect";
import NumberFilter from "./src/components/number";
import SelectFilter from "./src/components/select";
import TextFilter from "./src/components/text";
declare const _default: (options?: {}) => {
    createContext: (_: any, isRemoteFiltering: any, handleFilterChange: any) => {
        Provider: {
            new (props: any): {
                clearFilters: any;
                currFilters: any;
                data: any;
                isEmitDataChange: any;
                componentDidMount(): void;
                onFilter(column: any, filterType: any, initialize?: boolean): (filterVal: any) => void;
                onExternalFilter(column: any, filterType: any): (value: any) => void;
                getFiltered(): any;
                componentDidUpdate(nextProps: any): void;
                doFilter(props: any, ignoreEmitDataChange?: boolean): void; /**
                 * multiSelectFilter adds multi select filtering to a column
                 * @param props filter options
                 */
                /**
                 * Number filter configuration options
                 */
                render(): import("react").JSX.Element;
                context: unknown;
                setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<any>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<any>;
                state: Readonly<{}>;
                refs: {
                    [key: string]: import("react").ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): boolean;
                componentWillUnmount?(): void;
                componentDidCatch?(error: Error, errorInfo: import("react").ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<any>, prevState: Readonly<{}>): any;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<any>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<any>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): void;
            };
            propTypes: {
                data: PropTypes.Validator<any[]>;
                columns: PropTypes.Validator<any[]>;
                dataChangeListener: PropTypes.Requireable<object>;
            };
            contextType?: import("react").Context<any> | undefined;
        };
        Consumer: import("react").Consumer<any>;
    };
    options: {};
};
export default _default;
export declare const textFilter: (props?: {}) => {
    Filter: typeof TextFilter;
    props: {};
};
export declare const selectFilter: (props?: {}) => {
    Filter: typeof SelectFilter;
    props: {};
};
export declare const multiSelectFilter: (props?: {}) => {
    Filter: typeof MultiSelectFilter;
    props: {};
};
export declare const numberFilter: (props?: {}) => {
    Filter: typeof NumberFilter;
    props: {};
};
export declare const dateFilter: (props?: {}) => {
    Filter: typeof DateFilter;
    props: {};
};
export declare const customFilter: (props?: {}) => {
    props: {};
};
export declare enum FILTER_TYPES {
    TEXT = "TEXT",
    SELECT = "SELECT",
    MULTISELECT = "MULTISELECT",
    NUMBER = "NUMBER",
    DATE = "DATE"
}
export declare const FILTER_DELAY = 500;
/**
 * Filter comparators used for table filters
 */
export declare const LIKE = "LIKE";
export declare const EQ = "=";
export declare const NE = "!=";
export declare const GT = ">";
export declare const GE = ">=";
export declare const LT = "<";
export declare const LE = "<=";
export declare enum Comparator {
    LIKE = "LIKE",
    EQ = "=",
    NE = "!=",
    GT = ">",
    GE = ">=",
    LT = "<",
    LE = "<="
}
export type TextFilterProps<T extends object = any> = TableColumnFilterProps<string, T> & Partial<{
    /**
     *  default is false, and true will only work when comparator is LIKE
     */
    caseSensitive: boolean;
    comparator: Comparator;
    /**
     * on filter element click event
     */
    onClick?: ((e: SyntheticEvent) => void) | undefined;
    filterState?: any;
    column: any;
}>;
/**
 * text column filter
 * @param props text filter options
 */
/**
 * select filter option type
 */
export type SelectFilterOptions = {
    [index: string]: string;
} | Array<{
    value: number;
    label: string;
}>;
export type SelectFilterProps<T extends object = any> = TableColumnFilterProps<string, T> & {
    options: SelectFilterOptions | ((column: ColumnDescription<T>) => SelectFilterOptions);
    comparator?: Comparator | undefined;
    /**
     * When the default unset selection is hidden from dropdown
     */
    withoutEmptyOption?: boolean | undefined;
    filterState?: any;
    column: any;
    caseSensitive?: boolean;
};
/**
 * single select column filter
 * @param props Select filter options
 */
/**
 * Datatype that can be used as the multiselect filter option
 */
export interface MultiSelectFilterOptions {
    [index: string]: string;
}
/**
 * Multi Select filter options
 */
export type MultiSelectFilterProps<T extends object = any> = TableColumnFilterProps<string[], T> & {
    options: MultiSelectFilterOptions | (() => MultiSelectFilterOptions);
    comparator?: Comparator | undefined;
    /**
     * When set the default selection is hidden from dropdown
     */
    withoutEmptyOption?: boolean | undefined;
    filterState?: any;
    column: any;
    caseSensitive?: boolean;
};
/**
 * multiSelectFilter adds multi select filtering to a column
 * @param props filter options
 */
/**
 * Number filter configuration options
 */
export type NumberFilterProps<T extends object = any> = TableColumnFilterProps<{
    number: number | "";
    comparator: Comparator;
}, T> & {
    options?: number[] | undefined;
    comparators?: Comparator[] | undefined;
    /**
     * When set to true comparator dropdown does not show a "no selection" option
     */
    withoutEmptyComparatorOption?: boolean | undefined;
    withoutEmptyNumberOption?: boolean | undefined;
    comparatorClassName?: string | undefined;
    numberClassName?: string | undefined;
    comparatorStyle?: CSSProperties | undefined;
    numberStyle?: CSSProperties | undefined;
    defaultValue?: {
        number: number;
        comparator: Comparator;
    } | undefined;
    filterState?: any;
    column: any;
};
/**
 * Date filter options
 */
export interface DateFilterProps<T extends object = any> extends TableColumnFilterProps<Date, T> {
    withoutEmptyComparatorOption?: boolean | undefined;
    defaultValue?: {
        date?: Date;
        comparator?: Comparator;
    } | undefined;
    comparators?: Comparator[] | undefined;
    comparatorClassName?: string | undefined;
    dateClassName?: string | undefined;
    comparatorStyle?: CSSProperties | undefined;
    dateStyle?: CSSProperties | undefined;
    filterState?: any;
    column: any;
}
/**
 * Custom filter
 */
export interface CustomFilterProps {
    type?: string | FILTER_TYPES | undefined;
    comparator?: Comparator | undefined;
    caseSensitive?: boolean | undefined;
}
/**
 * declaration for table filter sub module
 */
export interface FilterFactoryProps<T extends object = any> {
    afterFilter?: ((newResult: T[], newFilters?: unknown[]) => void) | undefined;
}
